#
# spec file for package mate-applet-dock
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   mate-dock-applet
Name:           mate-applet-dock
Version:        21.10.0
Release:        1.10
Summary:        Dock applet for the MATE panel
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/ubuntu-mate/mate-dock-applet
Source:         https://github.com/ubuntu-mate/%{_name}/archive/%{version}.tar.gz#/%{_name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bamf-daemon
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  python3-devel
Requires:       bamf-daemon
Requires:       python3-Pillow
Requires:       python3-cairo
Requires:       python3-distro
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-gobject-cairo
Requires:       python3-python-xlib
Requires:       python3-pyxdg
Recommends:     libunity
%glib2_gsettings_schema_requires

%description
An application dock applet for the MATE panel.

The applet allows you to:
 * Place a dock on any MATE panel, of any size, on any side of the
   desktop you desire.
 * Pin and unpin applications to the dock.
 * Rearrange application icons on the dock.
 * Launch applications by clicking on their icons in the dock.
 * Minimise/restore the running application windows by clicking the
   applications dock icon.
 * Detect changes in the current icon theme and update the dock
   accordingly.
 * Use an indicator by each application to show when it is running.
 * Optionally, use multiple indicators for each window an
   application has opened.
 * Use either a light or dark indicator that it can always be seen
   no matter what colour the panel is.

%prep
%setup -q -n %{_name}-%{version}

%lang_package

%build
autoreconf -fi
%configure \
  --with-gtk3
%make_build

%install
%make_install
%fdupes %{buildroot}%{_libdir}/
%find_lang %{_name}

pushd %{buildroot}%{_libdir}/mate-applets/mate-dock-applet/
# Do not use env for python scripts.
sed -i '/^#!/s|env python3$|python3|' *.py
# Create Python bytecode.
rm -rf *.pyc *.pyo __pycache__/
touch -c *.py
%py3_compile .
popd

%files
%license COPYING
%doc AUTHORS ChangeLog README.md
%dir %{_libdir}/mate-applets/
%{_libdir}/mate-applets/mate-dock-applet/
%dir %{_datadir}/dbus-1/
%dir %{_datadir}/dbus-1/services/
%{_datadir}/dbus-1/services/org.mate.panel.applet.*.service
%{_datadir}/glib-2.0/schemas/*.gschema.xml
%dir %{_datadir}/mate-panel/
%dir %{_datadir}/mate-panel/applets/
%{_datadir}/mate-panel/applets/org.mate.panel.*.mate-panel-applet

%files lang -f %{_name}.lang

%changelog
* Sat Nov 20 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 21.10.0:
  * Only activate the topmost window for Unity-style window
    switching behaviour.
  * Add i18n support along with French and Spanish translations.
  * Fix AttributeError in start_app().
- Change the requirement from python3-xdg to python3-pyxdg.
- Add the mate-applet-dock-lang package.
* Sat Feb 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 20.04.0 (changes since 0.88):
  * Fix icon blinking when opening a minimised window.
  * Fix a typo in user application path.
  * Support pixbufs without an alpha channel.
  * Use the "distro" module for looking up distribution details.
  * Fix a few crashes.
- Drop support for old openSUSE versions.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 0.88:
  * Added Unity and Unity Flat looks to the dock.
  * Change the way in which the dock appearance is set in the
    preferences dialogue, so that preset "themes" or a custom mix
    of icon background and indicators can be applied.
  * Fix unpinned applications not minimising to their own button.
  * Fix MATE's Sticky Notes showing up in the Dock/
  * Fix extra space on the right side of the panel.
  * Add Unity-like icons backlight + gloss.
  * Fix double-click being needed, if panel not expaned.
  * Fix an issue where applications whose .desktop file specified a
    full path and filename for their desktop icon would not load
    the icon correctly.
* Sun Nov 25 2018 sor.alexei@meowr.ru
- Update to version 0.87 (changes since 0.83):
  * The workaround introduced in v0.83 has been adjusted following
    the removal of the workspace swticher applet from the Mutiny
    panel layout.
  * A workaround for a bug which affected Mutineers who switched
    panel layouts and found their dock settings had not been
    carried forward (lp#1755835).
  * Fix the icon staying highlighted with all windows closed.
  * Fix dock sizing options appearing in the preferences dialogue
    when not needed.
  * Fix application activation by dragging not working.
  * Fix icons for windows which the applet should have been
    ignoring appearing in the dock.
  * Fix the Telegram icon not being found; showed as generic cogs.
  * Fix dragging application icons not always working.
  * Fix certain function keys causing the keyboard listener to
    stop working.
  * Potential fix for blurry application icons on HiDPI.
  * Fix window previews with Compiz.
  * When an application's window is closed from the window list,
    the window list is now hidden.
  * Fix odd icon behaviour when minimising and then restoring.
  * Fix LibreOffice Writer not showing in the dock.
  * Remove unused event parameter.
  * Use the dark variant when defined by the theme.
  * Add a "bring all windows forward" option.
  * Fix AttributeError in do_window_scroll().
  * Fix icons of wine applications not being displayed.
  * All actions defined in a .desktop file are now displayed in the
    right click or pop-up menus rather. Previously a maximum of 4
    only would be displayed.
  * Fix being unable to restore some minimised windows.
- Add the bamf-daemon dependency.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 0.83 (changes since 0.77):
  * Add five new types of indicators.
  * Add a new option to specify the amount of space between icons
    in the dock.
  * Add a new option to specify how a dock icon reacts when an
    application requires attention. The icon can now either flash
    (the default) or display an exclamation mark over the icon.
  * The applet no longer swallows <Super> key presses. This means
    it now works happily alongside other applications that also use
    the <Super> key, e.g. the Brisk menu, the Advanced MATE Menu or
    Albert.
  * Fix crashes relating to Pango when window list and action_list
    contents needed to be ellipsised.
  * With Gtk3 and Python GObject bindings 3.26.0 or greater, window
    lists and action lists now have rounded corners and point to
    their application's icon in the dock.
  * Fix application icons continually flashing.
  * The delay before action lists appear when the mouse hovers over
    a dock icon can now be set in the preferences dialogue.
  * Applications can now be pinned to specific workspaces, in other
    words their application icons only appear in the dock when a
    particular workspace is active. This allows users to customise
    the dock for each workspace they use.
  * The applet right click menu no longer contains actions for the
    currently active application when popup action lists are
    enabled.
  * When unpinning an application a notification is now displayed
    which allows the operation to be undone and re-pins the
    application to the dock.
  * The appearance of progress bars on dock icons has been
    improved.
  * Remove built-in app matching code and replaced it with use of
    the bamf library.
  * The dock can now scroll application icons on MATE 1.18 and
    older. This feature is automatically enabled when using the
    Mutiny layout of MATE Tweak, and can also be manually
    configured by using a new preferences item.
  * Action lists and window lists no longer steal focus from other
    windows.
  * Solid filled active application backgrounds have been adjusted
    to provide better contrast with the panel.
  * Add a temporary workaround for gh#mate-desktop/mate-panel#745.
    This workaround will be removed when the issue is resolved.
- Avoid /usr/bin/env.
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 0.77:
  * Applications can be added to the dock by dragging them off
    menu applets (Main Menu, Menu Bar, Advanced Menu, Brisk Menu)
    and onto the applet (Gtk3 only).
  * If data is dragged from an app onto another running app's icon
    the new app will be made active, allowing the dragged data to
    dropped onto it (Gtk3 only).
  * Add keyboard shortcuts to select and acticate applications in
    the dock:
    + <Super>1-0 for the first 10 apps in the dock
    + <Super><Alt>1-0 for apps 10-20 in the dock
    For the 5th application, it would be necessary to hold down
    the Super key (i.e. the Windows key) and press 5. For the 12th
    application, it would be necessary to hold bown both the Super
    key and the Alt key and press 2.
    The effect of these shortcuts is as follows:
    + If the application is not running, it will be started.
    + If the application is running and only has a single window
    open, the window will cycled between minimised and activated
    states.
    + If the application is running and has multiple windows open,
    each keypress will activate and display each window in turn.
  * Update the About window to provide details of the new
    drag and drop and keyboard shortcuut features.
  * Fix a bug which prevented window and action lists from
    appearing.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Switch to Gtk3.
* Thu Jan 26 2017 sor.alexei@meowr.ru
- Update to version 0.76:
  * Add support for startup notification when launching
    applications.
  * Add a new indicator type - a single solid bar. On Gtk3 this
    uses the active theme's highlight colour.
  * Add new types of indicators and active icon backgrounds.
  * Add new preferences options to allow the select the type of
    indicator and active icon background, along with with a live
    preview.
  * Add a new preference item allowing the user to select a colour
    to use when drawing bar indicators.
  * About dialogue is reworked to hopefully be less ugly...
* Thu Jan 19 2017 sor.alexei@meowr.ru
- Update to version 0.75:
  * Fix a bug that caused window lists to sometimes span monitors
    on multi monitor systems.
  * Add Compiz support: the dock can now display window previews
    (via the Scale and D-Bus plugins) when switching between
    application windows rather than using the built in window list.
  * Mouse clicks on an application's dock icon now work differently:
    + If the application is not running, or if the Shift key is
    pressed while clicking, the application will be started / a
    new instance will be started.
    + If the application has only one window open, the window will
    be activated.
    + If the application has multiple windows open, the window list
    will be shown or the Compiz scale plugin will be activated,
    as appropriate.
  * The configuration option to restore all of application's
    windows or only the previously active one on a mouse click has
    been removed, and replace with a new one which allows the user
    to select between using the built in window list, or Compiz
    window previews.
  * The window list no longer contains application actions,
    e.g. Pin/Unpin, or e.g. 'New Document' for LibreOffice Writer).
  * Application actions now appear in a separate popup window in
    the same way that the window list used to, by hovering the
    mouse over the dock icon. The actions are also available by
    right clicking on the application icon and selecting them from
    the panel popup menu.
  * A new configuration option has been added to prevent the popup
    windows appearing in case users want to select actions from the
    right click menu only.
  * GTK+3 only: the colour of window lists and action popups now
    match the panel which contains the applet, whether the panel is
    set to use a colour from the current theme or a custom colour.
* Sun Aug 28 2016 sor.alexei@meowr.ru
- Update to version 0.74:
  * Correct position of window lists on non-expanded panels.
  * Fix for window list flickering on bottom aligned panels on MATE
    built with Gtk3.
  * Increase the delay before window lists are shown when the mouse
    hovers over an application icon. It was 0.5 seconds, and is now
    1 second.
  * Shortened pin/unpin window list text. It now says
    'Pin <application name>' rather than
    'Pin <application name> to the dock', and the Unpin text is
    similarly shortened.
  * Fix a bug that would cause Pin/Unpin actions to act upon
    previously highlighted application icons, rather than the one
    that is currently highlighted.
  * When starting to drag an application icon, the window list is
    now hidden.
  * The applet can now display progress bars and counts on
    application icons for applications which support this e.g. the
    Ubuntu software updater.
  * Fix for improved matching of binary packaged applications on
    Gentoo.
* Fri Jul 22 2016 sor.alexei@meowr.ru
- Update to version 0.73 (changes since 0.71):
  * The applet now works on and can be built for both Gtk2 and Gtk3
    versions of MATE.
  * Gtk3: Reimplement drag and drop rearranging of dock icons.
  * Rework window list which appears when the mouse hovers over a
    dock icon.
* Wed May  4 2016 sor.alexei@meowr.ru
- Update to version 0.71:
  * More improvements to matching applications with their .desktop
    files.
  * Application icons can now be sourced from the 'hicolor'
    directory.
  * The window list now displays the title of the active window in
    bold and italicised text.
  * Remove the options to display pinned applications from all or
    only the current workspace as these were based on a
    misunderstanding of a feature request. They have been replaced
    with a new option to only show indicators and window list
    items for windows which are on the current workspace and this
    provides the requested functionality.
  * Add a 'Hints and Tips' window accessible from the About dialog
    as a place to list useful keyboard shortcuts etc.
- Add missing python3-gobject-cairo, python3-gobject-Gdk
  dependencies.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 0.70 (changes since 0.67):
  * Fix for lp#1550392.
  * Add code to allow new instances of applications to be started
    by middle clicking their dock icons (lp#1554128).
  * Fix a bug that would prevent applications from launching if
    they were in a directory structure which contained a space
    character e.g. ~/foo bar/.
  * Fix a bug which associated newly opened windows with incorrect
    applications and which occurred when the wm_class_name of the
    window was not set (lp#1555324).
  * Settings from previous instances of the applet are now imported
    silently (previously the user was presented with a dialog
    asking the user if they wanted to import the settings). The
    change is to prevent problems when switching to the Mutiny
    desktop layout via MATE Tweak.
  * When saving custom launchers the ~/.local/share/applications
    directory will be created if it doesn't already exist.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 0.67:
  * Panel colour changing now occurs smoothly over 0.5s rather
    than abruptly.
  * Big cleanup of git repository.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Update to 0.66:
  * Improve matching applications with their .desktop files, in
    particular Opera and Chrome.
  * Dock icons now pulse when a new window is opened for a running
    application.
  * Minimise targets are now recalculated when the applet is moved
    or changes panel, so that windows always minimise to the
    correct place on the dock.
  * Add option to change MATE panel colour according to the
    current desktop wallpaper (note: this works for images only,
    not slideshows, gradients, or solid colour backgrounds). The
    colour can be applied to all panels or just the panel
    containing the dock. The applet now depends on the
    Python Imaging Library and SciPy packages because of this
    change.
  * Add new preferences to options to both activate panel colour
    changing  and to limit it to the dock panel panel only.
  * Add option to not display indicators under running applications.
  * Add option to not display in the dock running pinned
    applications which are not on the current workspace.
  * Using the mouse wheel on a dock icon to scroll through the
    application's windows will now change workspace if the new
    window is not on the current workspace.
  * Selecting an application's window from the pop-up window list
    will now change workspace if the window is not on the current
    workspace.
  * Preferences dialog reworked because of new options added in
    this version.
- Add missing python3-gobject and python3-cairo dependencies.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Update to 0.65:
  * Dock icons now blink when an application needs attention.
  * Change to window activation code for applet to work with
    MATE 1.12.
* Wed Oct 21 2015 sor.alexei@meowr.ru
- Update to 0.64:
  * Fix a bug that would sometimes prevent a window from being
    focused when a dock icon was clicked.
  * Many changes to improve detection of .desktop files from
    running applications and linking to dock icons.
  * Right click options (e.g. 'Open new Window' and Open new
    incognito window with Chromium) are now read from .desktop
    files and appear on	the dock icon right click menu.
  * Custom launchers now set the Type field of the .desktop files
    they create to 'Application' and also set the NoDisplay field
    to 'true' so that the launcher is not displayed in the MATE menu.
  * Customer launchers now write .desktop files that do not contain
    spaces in the filename, as per the GNOME developer docs.
  * Application icons can now be sourced from ~/.local/share/icons/.
* Fri Jul 24 2015 sor.alexei@meowr.ru
- Update to 0.63:
  * Remove the tooltip that appears when the mouse hovers over a
    docked app and replace it with a list of the app's open windows.
    For each window, the list displays the app icon, an indicator
    showing which window is currently active, the window title, and
    a close icon.
  * Clicking the close icon closes the window, clicking anywhere
    else makes the window active.
  * Remove the list of app windows from the applet right click menu
    as they are no longer required.
  * Change the way the applet works when a running app's dock icon
    is clicked. This no longer minimizes/maximises all windows, but
    simply activates the app's last active window.
  * Using the mouse scroll wheel over a running app's dock icon now
    scrolls through each of the app's open windows, unminimizing
    them and activating them as necessary .desktop files located in
    the user's home directory now take precedence over those
    located elsewhere in the filesystem. This allows users to create
    their own .desktop files (e.g. to customize an app's icon) and
    have them recognized by the applet.
  * Change factory service file to explicitly invoke applet with
    python 3.
  * The applet now saves its settings in
    ~/.config/mate_dock_applet.conf as well as in dconf. On first
    being added to a panel, the applet checks to see if this file
    exists and if it does it offers to use this configuration. This
    allows e.g. an easy way to restore the applet after an
    accidental deletion from the panel, and also a way to move
    applet configurations from one computer to another.
* Mon Jun 29 2015 cfarrell@suse.com
- license update: GPL-2.0+
  No GPL-3.0 instances found
* Tue Jun 16 2015 sor.alexei@meowr.ru
- Update to 0.62:
  * Fix app icon drawing on non-composited displays.
  * For apps which the applet does not recognise (their names or
    icons are incorrect) add a new right click menu option on the
    dock to create a custom launcher for the app. This displays a
    dialog (like the one for the MATE panel) allowing the app's
    command line, name, and icon to be specified. For user
    convenience, the applet will  automatically fill in as many of
    these details as it can. Once the new launcher has been created,
    the application needs to be closed and reopened for it to be
    recognised by the dock. Typically, this option will only be
    needed for applications which have not been installed into the
    usual locations within the Linux filesystem.
  * When an applications windows are minimised by clicking on the
    applications dock icon and then maximised by clicking it again,
    the application window that	was previously active is made
    active again.
* Thu May 28 2015 sor.alexei@meowr.ru
- Initial package.
